# PyNucSeg
A python package for segmentation of fluorescent nucleus, and measure the area of nucleus and the mean intensity per nucleus. This package uses `stardist` (https://github.com/stardist/stardist) for segmentation, and `napari` (https://github.com/napari/napari) for visualization.

## Installation
Run the follwing to install:
```python
pip install pynucseg
```
## Import

```python
from pynucseg import ReferenceImage
```
